- added upstream patch to fix rhbz#638345

This commit is contained in:
Daniel Kopecek 2010-09-29 10:26:02 +02:00
parent 9714d256ce
commit ecddd163e2
2 changed files with 22 additions and 1 deletions

View File

@ -0,0 +1,15 @@
diff -r 9a328aa25c53 -r a686884684ca linux_audit.c
--- a/linux_audit.c Fri Sep 17 12:13:17 2010 -0400
+++ b/linux_audit.c Tue Sep 21 07:56:36 2010 -0400
@@ -81,9 +81,9 @@
}
*--cp = '\0';
/* Log command, ignoring EPERM on error. */
rc = audit_log_user_command(au_fd, AUDIT_USER_CMD, command, NULL, result);
- if (rc <= 0)
+ if (rc <= 0 && errno != ECONNREFUSED)
warning("unable to send audit message");
efree(command);

View File

@ -1,7 +1,7 @@
Summary: Allows restricted root access for specified users
Name: sudo
Version: 1.7.4p4
Release: 3%{?dist}
Release: 4%{?dist}
License: ISC
Group: Applications/System
URL: http://www.courtesan.com/sudo/
@ -32,6 +32,8 @@ Patch4: sudo-1.7.4p3-sudolist.patch
Patch5: sudo-1.7.4p4-getgrouplist.patch
# reset HOME when using the `-i' option (#635250)
Patch6: sudo-1.7.4p4-sudoi.patch
# Ignore ECONREFUSED from audit_log_user_command()
Patch7: sudo-1.7.4p4-auditconn.patch
%description
Sudo (superuser do) allows a system administrator to give certain
@ -53,6 +55,7 @@ on many different machines.
%patch4 -p1 -b .sudolist
%patch5 -p1 -b .getgrouplist
%patch6 -p0 -b .sudoi
%patch7 -p1 -b .auditconn
%build
# handle newer autoconf
@ -147,6 +150,9 @@ rm -rf $RPM_BUILD_ROOT
/bin/chmod 0440 /etc/sudoers || :
%changelog
* Wed Sep 29 2010 Daniel Kopecek <dkopecek@redhat.com> - 1.7.4p4-4
- added upstream patch to fix rhbz#638345
* Mon Sep 20 2010 Daniel Kopecek <dkopecek@redhat.com> - 1.7.4p4-3
- added patch for #635250
- /var/run/sudo -> /var/db/sudo in .spec
@@ -81,9 +81,9 @@
}
*--cp = '\0';
- /* Log command, ignoring EPERM on error. */
+ /* Log command, ignoring ECONNREFUSED on error. */
rc = audit_log_user_command(au_fd, AUDIT_USER_CMD, command, NULL, result);